@@ -3,8 +3,10 @@
 # file, you can obtain one at http://mozilla.org/MPL/2.0/.
 import pytest
 
+import dockerflow.checks.registry
 
-@pytest.fixture
+
+@pytest.fixture()
 def version_content():
     """
     as documented on https://github.com/mozilla-services/Dockerflow/blob/main/docs/version_object.md
@@ -15,3 +17,9 @@ def version_content():
         "commit": "<git hash>",
         "build": "uri to CI build job",
     }
+
+
+@pytest.fixture(autouse=True)
+def _clear_checks():
+    yield
+    dockerflow.checks.registry.clear_checks()
