@@ -4,7 +4,7 @@ import logging
 from logging.config import fileConfig
 
 from alembic import context  # no:qa
-from flask import current_app  # noqa
+from flask import current_app
 from sqlalchemy import engine_from_config, pool
 
 # this is the Alembic Config object, which provides
@@ -24,7 +24,7 @@ target_metadata = current_app.extensions["migrate"].db.metadata
 
 # other values from the config, defined by the needs of env.py,
 # can be acquired:
-# my_important_option = config.get_main_option("my_important_option")
+# my_important_option = config.get_main_option("my_important_option")  # noqa
 # ... etc.
 
 
