@@ -13,11 +13,22 @@ from flask_login import LoginManager, current_user, login_user
 from flask_login.mixins import UserMixin
 from flask_migrate import Migrate
 from flask_redis import FlaskRedis
-from flask_sqlalchemy import SQLAlchemy, get_debug_queries
+from flask_sqlalchemy import SQLAlchemy
 from sqlalchemy.exc import DBAPIError, SQLAlchemyError
 
-from dockerflow import health
-from dockerflow.flask import Dockerflow, checks
+from dockerflow import checks, health
+from dockerflow.flask import Dockerflow
+from dockerflow.flask.checks import (
+    check_database_connected,
+    check_migrations_applied,
+    check_redis_connected,
+)
+
+try:
+    from flask_sqlalchemy.record_queries import get_recorded_queries
+except ImportError:
+    # flask-sqlalchemy < 3
+    from flask_sqlalchemy import get_debug_queries as get_recorded_queries
 
 
 class MockUser(UserMixin):
@@ -29,7 +40,8 @@ def load_user(user_id):
     return MockUser(user_id)
 
 
-def create_app():
+@pytest.fixture()
+def app():
     app = Flask("dockerflow")
     app.secret_key = "super sekrit"
     login_manager = LoginManager(app)
@@ -37,30 +49,36 @@ def create_app():
     return app
 
 
-@pytest.fixture
-def app():
-    return create_app()
+@pytest.fixture()
+def client(app):
+    return app.test_client()
 
 
-@pytest.fixture
+@pytest.fixture()
 def dockerflow(app):
     return Dockerflow(app)
 
 
-@pytest.fixture
+@pytest.fixture()
+def _setup_request_summary_logger(dockerflow):
+    dockerflow.summary_logger.addHandler(logging.NullHandler())
+    dockerflow.summary_logger.setLevel(logging.INFO)
+
+
+@pytest.fixture()
 def db(app):
     app.config["SQLALCHEMY_DATABASE_URI"] = "sqlite://"
     app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False
     return SQLAlchemy(app)
 
 
-@pytest.fixture
+@pytest.fixture()
 def migrate(app, db):
     test_migrations = os.path.join(os.path.dirname(__file__), "migrations")
     return Migrate(app, db, directory=test_migrations)
 
 
-@pytest.fixture
+@pytest.fixture()
 def redis_store(app):
     return FlaskRedis.from_custom_provider(FakeStrictRedis, app)
 
@@ -72,28 +90,23 @@ def test_instantiating(app):
     assert "dockerflow.heartbeat" in app.view_functions
 
 
-def test_version_exists(dockerflow, mocker, app, version_content):
+def test_version_exists(dockerflow, mocker, version_content, client):
     mocker.patch.object(dockerflow, "_version_callback", return_value=version_content)
-    response = app.test_client().get("/__version__")
+    response = client.get("/__version__")
     assert response.status_code == 200
     assert json.loads(response.data.decode()) == version_content
 
 
-def test_version_path(mocker, version_content):
-    app = Flask("dockerflow")
-    app.secret_key = "super sekrit"
-    login_manager = LoginManager(app)
-    login_manager.user_loader(load_user)
+def test_version_path(mocker, app, client, version_content):
     custom_version_path = "/something/extra/ordinary"
     dockerflow = Dockerflow(app, version_path=custom_version_path)
     version_callback = mocker.patch.object(
         dockerflow, "_version_callback", return_value=version_content
     )
-    with app.test_client() as test_client:
-        response = test_client.get("/__version__")
-        assert response.status_code == 200
-        assert json.loads(response.data.decode()) == version_content
-        version_callback.assert_called_with(custom_version_path)
+    response = client.get("/__version__")
+    assert response.status_code == 200
+    assert json.loads(response.data.decode()) == version_content
+    version_callback.assert_called_with(custom_version_path)
 
 
 def test_version_missing(dockerflow, mocker, app):
@@ -115,21 +128,18 @@ def test_version_callback(dockerflow, app):
 
 
 def test_heartbeat(app, dockerflow):
-    # app.debug = True
-    dockerflow.checks.clear()
-
     response = app.test_client().get("/__heartbeat__")
     assert response.status_code == 200
 
-    @dockerflow.check
+    @checks.register
     def error_check():
         return [checks.Error("some error", id="tests.checks.E001")]
 
-    @dockerflow.check()
+    @checks.register()
     def warning_check():
         return [checks.Warning("some warning", id="tests.checks.W001")]
 
-    @dockerflow.check(name="warning-check-two")
+    @checks.register(name="warning-check-two")
     def warning_check2():
         return [checks.Warning("some other warning", id="tests.checks.W002")]
 
@@ -143,19 +153,57 @@ def test_heartbeat(app, dockerflow):
     assert "warning-check-two" in defaults
 
 
+def test_heartbeat_silenced_checks(app):
+    Dockerflow(app, silenced_checks=["tests.checks.W001"])
+
+    @checks.register
+    def error_check():
+        return [checks.Error("some error", id="tests.checks.E001")]
+
+    @checks.register
+    def warning_check():
+        return [checks.Warning("some warning", id="tests.checks.W001")]
+
+    response = app.test_client().get("/__heartbeat__")
+    assert response.status_code == 500
+    payload = json.loads(response.data.decode())
+    assert payload["status"] == "error"
+    details = payload["details"]
+    assert "error_check" in details
+    assert "warning_check" not in details
+
+
+def test_heartbeat_logging(app, dockerflow, caplog):
+    @checks.register
+    def error_check():
+        return [checks.Error("some error", id="tests.checks.E001")]
+
+    @checks.register()
+    def warning_check():
+        return [checks.Warning("some warning", id="tests.checks.W001")]
+
+    with caplog.at_level(logging.INFO, logger="dockerflow.checks.registry"):
+        app.test_client().get("/__heartbeat__")
+
+    logged = [(record.levelname, record.message) for record in caplog.records]
+    assert ("ERROR", "tests.checks.E001: some error") in logged
+    assert ("WARNING", "tests.checks.W001: some warning") in logged
+
+
 def test_lbheartbeat_makes_no_db_queries(dockerflow, app):
-    assert len(get_debug_queries()) == 0
-    response = app.test_client().get("/__lbheartbeat__")
-    assert response.status_code == 200
-    assert len(get_debug_queries()) == 0
+    with app.app_context():
+        assert len(get_recorded_queries()) == 0
+        response = app.test_client().get("/__lbheartbeat__")
+        assert response.status_code == 200
+        assert len(get_recorded_queries()) == 0
 
 
 def test_full_redis_check(mocker):
     app = Flask("redis-check")
     app.debug = True
     redis_store = FlaskRedis.from_custom_provider(FakeStrictRedis, app)
-    dockerflow = Dockerflow(app, redis=redis_store)
-    assert "check_redis_connected" in dockerflow.checks
+    Dockerflow(app, redis=redis_store)
+    assert "check_redis_connected" in checks.get_checks()
 
     with app.test_client() as test_client:
         response = test_client.get("/__heartbeat__")
@@ -168,8 +216,8 @@ def test_full_redis_check_error(mocker):
     redis_store = FlaskRedis.from_custom_provider(FakeStrictRedis, app)
     ping = mocker.patch.object(redis_store, "ping")
     ping.side_effect = redis.ConnectionError
-    dockerflow = Dockerflow(app, redis=redis_store)
-    assert "check_redis_connected" in dockerflow.checks
+    Dockerflow(app, redis=redis_store)
+    assert "check_redis_connected" in checks.get_checks()
 
     with app.test_client() as test_client:
         response = test_client.get("/__heartbeat__")
@@ -177,37 +225,56 @@ def test_full_redis_check_error(mocker):
         assert json.loads(response.data.decode())["status"] == "error"
 
 
-def test_full_db_check(mocker):
-    app = Flask("db-check")
-    app.config["SQLALCHEMY_DATABASE_URI"] = "sqlite://"
-    app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False
-    db = SQLAlchemy(app)
-    dockerflow = Dockerflow(app, db=db)
-    assert "check_database_connected" in dockerflow.checks
+def test_full_db_check(mocker, app, db, client):
+    Dockerflow(app, db=db)
+    assert "check_database_connected" in checks.get_checks()
 
-    response = app.test_client().get("/__heartbeat__")
+    response = client.get("/__heartbeat__")
     assert response.status_code == 200
     assert json.loads(response.data.decode())["status"] == "ok"
 
 
-def test_full_db_check_error(mocker):
-    app = Flask("db-check")
-    app.config["SQLALCHEMY_DATABASE_URI"] = "sqlite://"
-    app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False
-    db = SQLAlchemy(app)
-
-    engine_connect = mocker.patch.object(db.engine, "connect")
-    engine_connect.side_effect = SQLAlchemyError
-    dockerflow = Dockerflow(app, db=db)
-    assert "check_database_connected" in dockerflow.checks
-
-    with app.test_client() as test_client:
-        response = test_client.get("/__heartbeat__")
+def test_full_db_check_error(mocker, app, db, client):
+    with app.app_context():
+        mocker.patch.object(db.engine, "connect", side_effect=SQLAlchemyError)
+        Dockerflow(app, db=db)
+        assert "check_database_connected" in checks.get_checks()
+        response = client.get("/__heartbeat__")
         assert response.status_code == 500
         assert json.loads(response.data.decode())["status"] == "error"
 
 
-def assert_log_record(request, record, errno=0, level=logging.INFO):
+def test_full_migrate_check(mocker, client, app, db, migrate):
+    mocker.patch(
+        "alembic.script.ScriptDirectory.get_heads", return_value=("17164a7d1c2e",)
+    )
+    mocker.patch(
+        "alembic.migration.MigrationContext.get_current_heads",
+        return_value=("17164a7d1c2e",),
+    )
+    Dockerflow(app, migrate=migrate)
+    with app.app_context():
+        assert "check_migrations_applied" in checks.get_checks()
+        response = client.get("/__heartbeat__")
+        assert response.status_code == 200
+        assert json.loads(response.data.decode())["status"] == "ok"
+
+
+def test_full_migrate_check_error(mocker, client, app, db, migrate):
+    with app.app_context():
+        mocker.patch.object(db.engine, "connect", side_effect=SQLAlchemyError)
+        Dockerflow(app, migrate=migrate)
+        assert "check_migrations_applied" in checks.get_checks()
+        response = client.get("/__heartbeat__")
+        assert response.status_code == 200
+        assert response.json["status"] == "info"
+        assert (
+            health.INFO_CANT_CHECK_MIGRATIONS
+            in response.json["details"]["check_migrations_applied"]["messages"]
+        )
+
+
+def assert_log_record(record, errno=0, level=logging.INFO):
     assert record.levelno == level
     assert record.errno == errno
     assert record.agent == "dockerflow/tests"
@@ -221,17 +288,30 @@ def assert_log_record(request, record, errno=0, level=logging.INFO):
 headers = {"User-Agent": "dockerflow/tests", "Accept-Language": "tlh"}
 
 
-def test_request_summary(caplog, dockerflow, app):
-    with app.test_client() as test_client:
-        test_client.get("/", headers=headers)
-        assert getattr(g, "_request_id") is not None
+@pytest.mark.usefixtures("_setup_request_summary_logger")
+def test_request_summary(caplog, app, client):
+    caplog.set_level(logging.INFO)
+    with app.test_request_context("/"):
+        client.get("/", headers=headers)
         assert getattr(g, "request_id") is not None
         assert isinstance(getattr(g, "_start_timestamp"), float)
 
         assert len(caplog.records) == 1
-        for record in caplog.records:
-            assert_log_record(request, record)
-            assert getattr(request, "uid", None) is None
+        record = caplog.records[0]
+        assert_log_record(record)
+        assert getattr(request, "uid", None) is None
+
+
+@pytest.mark.usefixtures("_setup_request_summary_logger")
+def test_request_summary_querystring(caplog, app, client):
+    app.config["DOCKERFLOW_SUMMARY_LOG_QUERYSTRING"] = True
+    caplog.set_level(logging.INFO)
+    with app.test_request_context("/"):
+        client.get("/?x=شكر", headers=headers)
+
+        assert len(caplog.records) == 1
+        record = caplog.records[0]
+        assert record.querystring == "x=شكر"
 
 
 def test_preserves_existing_request_id(dockerflow, app):
@@ -256,17 +336,20 @@ def assert_user(app, caplog, user, callback):
         response = Response("")
         response = app.process_response(response)
         assert len(caplog.records) == 1
-        for record in caplog.records:
-            assert_log_record(request, record)
-            assert record.uid == callback(user)
+        record = caplog.records[0]
+        assert_log_record(record)
+        assert record.uid == callback(user)
 
 
-def test_request_summary_user_success(caplog, dockerflow, mocker, app):
+def test_request_summary_user_success(caplog, dockerflow, app):
+    caplog.set_level(logging.INFO)
     user = MockUser(100)
     assert_user(app, caplog, user, lambda user: user.get_id())
 
 
 def test_request_summary_user_is_authenticated_missing(caplog, dockerflow, app):
+    caplog.set_level(logging.INFO)
+
     class MissingIsAuthenticatedUser(object):
         id = 0
         is_active = True
@@ -278,6 +361,8 @@ def test_request_summary_user_is_authenticated_missing(caplog, dockerflow, app):
 
 
 def test_request_summary_user_is_authenticated_callable(caplog, dockerflow, app):
+    caplog.set_level(logging.INFO)
+
     class CallableIsAuthenticatedUser(object):
         id = 0
         is_active = True
@@ -292,6 +377,7 @@ def test_request_summary_user_is_authenticated_callable(caplog, dockerflow, app)
 
 
 def test_request_summary_user_flask_login_missing(caplog, dockerflow, app, monkeypatch):
+    caplog.set_level(logging.INFO)
     monkeypatch.setattr("dockerflow.flask.app.has_flask_login", False)
     user = MockUser(100)
     assert_user(app, caplog, user, lambda user: "")
@@ -314,38 +400,41 @@ def test_request_summary_exception(caplog, app):
 
 
 def test_request_summary_failed_request(caplog, dockerflow, app):
+    caplog.set_level(logging.INFO)
+
     @app.before_request
     def hostile_callback():
-        # simulating resetting request changes
         delattr(g, "_request_id")
+        # simulating resetting request changes
         delattr(g, "_start_timestamp")
 
     app.test_client().get("/", headers=headers)
     assert len(caplog.records) == 1
     record = caplog.records[0]
-    assert getattr(record, "rid", None) is None
+    assert getattr(record, "rid", None) is not None
     assert getattr(record, "t", None) is None
 
 
-def test_db_check_sqlalchemy_error(mocker, db):
-    engine_connect = mocker.patch.object(db.engine, "connect")
-    engine_connect.side_effect = SQLAlchemyError
-    errors = checks.check_database_connected(db)
+def test_db_check_sqlalchemy_error(app, mocker, db):
+    with app.app_context():
+        mocker.patch.object(db.engine, "connect", side_effect=SQLAlchemyError)
+        errors = check_database_connected(db)
     assert len(errors) == 1
     assert errors[0].id == health.ERROR_SQLALCHEMY_EXCEPTION
 
 
-def test_db_check_dbapi_error(mocker, db):
-    exception = DBAPIError.instance("", [], Exception(), Exception)
-    engine_connect = mocker.patch.object(db.engine, "connect")
-    engine_connect.side_effect = exception
-    errors = checks.check_database_connected(db)
+def test_db_check_dbapi_error(app, mocker, db):
+    with app.app_context():
+        exception = DBAPIError.instance("", [], Exception(), Exception)
+        mocker.patch.object(db.engine, "connect", side_effect=exception)
+        errors = check_database_connected(db)
     assert len(errors) == 1
     assert errors[0].id == health.ERROR_DB_API_EXCEPTION
 
 
-def test_db_check_success(db):
-    errors = checks.check_database_connected(db)
+def test_db_check_success(app, db):
+    with app.app_context():
+        errors = check_database_connected(db)
     assert errors == []
 
 
@@ -374,16 +463,16 @@ def test_check_message():
     [SQLAlchemyError(), DBAPIError.instance("", [], Exception(), Exception)],
 )
 def test_check_migrations_applied_cannot_check_migrations(
-    exception, mocker, db, migrate
+    exception, mocker, app, db, migrate
 ):
-    engine_connect = mocker.patch.object(db.engine, "connect")
-    engine_connect.side_effect = exception
-    errors = checks.check_migrations_applied(migrate)
+    with app.app_context():
+        mocker.patch.object(db.engine, "connect", side_effect=exception)
+        errors = check_migrations_applied(migrate)
     assert len(errors) == 1
     assert errors[0].id == health.INFO_CANT_CHECK_MIGRATIONS
 
 
-def test_check_migrations_applied_success(mocker, db, migrate):
+def test_check_migrations_applied_success(mocker, app, db, migrate):
     get_heads = mocker.patch(
         "alembic.script.ScriptDirectory.get_heads", return_value=("17164a7d1c2e",)
     )
@@ -391,13 +480,14 @@ def test_check_migrations_applied_success(mocker, db, migrate):
         "alembic.migration.MigrationContext.get_current_heads",
         return_value=("17164a7d1c2e",),
     )
-    errors = checks.check_migrations_applied(migrate)
+    with app.app_context():
+        errors = check_migrations_applied(migrate)
     assert get_heads.called
     assert get_current_heads.called
     assert len(errors) == 0
 
 
-def test_check_migrations_applied_unapplied_migrations(mocker, db, migrate):
+def test_check_migrations_applied_unapplied_migrations(mocker, app, db, migrate):
     get_heads = mocker.patch(
         "alembic.script.ScriptDirectory.get_heads", return_value=("7f447c94347a",)
     )
@@ -405,7 +495,8 @@ def test_check_migrations_applied_unapplied_migrations(mocker, db, migrate):
         "alembic.migration.MigrationContext.get_current_heads",
         return_value=("73d96d3120ff",),
     )
-    errors = checks.check_migrations_applied(migrate)
+    with app.app_context():
+        errors = check_migrations_applied(migrate)
     assert get_heads.called
     assert get_current_heads.called
     assert len(errors) == 1
@@ -413,7 +504,7 @@ def test_check_migrations_applied_unapplied_migrations(mocker, db, migrate):
 
 
 @pytest.mark.parametrize(
-    "exception,error",
+    ("exception", "error"),
     [
         (redis.ConnectionError, health.ERROR_CANNOT_CONNECT_REDIS),
         (redis.RedisError, health.ERROR_REDIS_EXCEPTION),
@@ -422,7 +513,7 @@ def test_check_migrations_applied_unapplied_migrations(mocker, db, migrate):
 def test_check_redis_connected(mocker, redis_store, exception, error):
     ping = mocker.patch.object(redis_store, "ping")
     ping.side_effect = exception
-    errors = checks.check_redis_connected(redis_store)
+    errors = check_redis_connected(redis_store)
     assert len(errors) == 1
     assert errors[0].id == error
 
@@ -430,11 +521,11 @@ def test_check_redis_connected(mocker, redis_store, exception, error):
 def test_check_redis_connected_ping_check(mocker, redis_store):
     ping = mocker.patch.object(redis_store, "ping")
     ping.return_value = True
-    errors = checks.check_redis_connected(redis_store)
+    errors = check_redis_connected(redis_store)
     assert len(errors) == 0
 
     ping.return_value = False
-    errors = checks.check_redis_connected(redis_store)
+    errors = check_redis_connected(redis_store)
     assert len(errors) == 1
     assert errors[0].id == health.ERROR_REDIS_PING_FAILED
 
@@ -444,3 +535,23 @@ def test_checks_imports():
     from dockerflow.flask.checks.messages import level_to_text as b
 
     assert a == b
+
+
+def test_heartbeat_checks_legacy(dockerflow, client):
+    dockerflow.checks.clear()
+
+    @dockerflow.check
+    def error_check():
+        return [checks.Error("some error", id="tests.checks.E001")]
+
+    def error_check_partial(obj):
+        return [checks.Error(repr(obj), id="tests.checks.E001")]
+
+    dockerflow.init_check(error_check_partial, ("foo", "bar"))
+
+    response = client.get("/__heartbeat__")
+    assert response.status_code == 500
+    payload = response.json
+    assert payload["status"] == "error"
+    assert "error_check" in payload["details"]
+    assert "('foo', 'bar')" in str(payload["details"]["error_check_partial"])
